@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Apache2 API Framework - ~/lib/Apache2/API.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2023/05/30
-## Modified 2023/05/31
+## Modified 2023/06/11
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -27,7 +27,7 @@ BEGIN
     use Apache2::ServerUtil ();
     use Apache2::RequestUtil ();
     use Apache2::Response ();
-    use Apache2::Log;
+    use Apache2::Log ();
     use Apache2::API::Request;
     use Apache2::API::Response;
     use Apache2::API::Status;
@@ -39,7 +39,7 @@ BEGIN
     use Nice::Try dont_want => 1;
     use Scalar::Util ();
     $DEBUG   = 0;
-    $VERSION = 'v0.1.0';
+    $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -66,20 +66,34 @@ sub import
 sub init
 {
     my $self = shift( @_ );
-    my $r = shift( @_ ) || Apache2::RequestUtil->request;
+    my $r;
+    $r = shift( @_ ) if( @_ % 2 );
+    # my $r = shift( @_ ) || Apache2::RequestUtil->request;
     $self->{request}                = undef unless( $self->{request} );
     $self->{response}               = undef unless( $self->{response} );
-    $self->{apache_request}         = undef unless( $self->{apache_request} );
+    $self->{apache_request}         = $r unless( $self->{apache_request} );
     # 200Kb
     $self->{compression_threshold}  = 204800 unless( length( $self->{compression_threshold} ) );
     $self->SUPER::init( @_ ) || return( $self->pass_error );
-    $self->apache_request( $r ) || return( $self->pass_error );
-    my $req = Apache2::API::Request->new( $r, debug => $DEBUG ) ||
-        return( $self->pass_error( Apache2::API::Request->error ) );
-    my $resp = Apache2::API::Response->new( request => $req, debug => $DEBUG ) ||
-        return( $self->pass_error( Apache2::API::Response->error ) );
-    $self->request( $req );
-    $self->response( $resp );
+    unless( $r = $self->apache_request )
+    {
+        $r ||= Apache2::RequestUtil->request;
+        return( $self->error( "No Apache2::RequestRec object was provided." ) ) if( !$r );
+        $self->apache_request( $r ) || return( $self->pass_error );
+    }
+    my( $req, $resp );
+    unless( $req = $self->request )
+    {
+        $req = Apache2::API::Request->new( $r, debug => $self->debug ) ||
+            return( $self->pass_error( Apache2::API::Request->error ) );
+        $self->request( $req );
+    }
+    unless( $resp = $self->response )
+    {
+        $resp = Apache2::API::Response->new( request => $req, debug => $self->debug ) ||
+            return( $self->pass_error( Apache2::API::Response->error ) );
+        $self->response( $resp );
+    }
     return( $self );
 }
 
@@ -738,6 +752,9 @@ Apache2::API - Apache2 API Framework
     # with Apache2::RequestUtil->request
     my $api = Apache2::API->new( $r, compression_threshold => 204800 ) ||
         die( Apache2::API->error );
+    # or:
+    my $api = Apache2::API->new( apache_request => $r, compression_threshold => 204800 ) ||
+        die( Apache2::API->error );
 
     # or even inside your mod_perl script/cgi:
     #!/usr/bin/perl
@@ -805,7 +822,7 @@ Apache2::API - Apache2 API Framework
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
@@ -818,11 +835,21 @@ Apache mod_perl is an awesome framework, but quite complexe with a steep learnin
 =head2 new
 
     my $api = Apache2::API->new( $r, $hash_ref_of_options );
+    # or
+    my $api = Apache2::API->new( apache_request => $r, compression_threshold => 102400 );
 
-This initiates the package and takes an L<Apache2::RequestRec> object and an hash or hash reference of parameters:
+This initiates the package and takes an L<Apache2::RequestRec> object and an hash or hash reference of parameters, or only an hash or hash reference of parameters:
 
 =over 4
 
+=item * C<apache_request>
+
+See L</apache_request>
+
+=item * C<compression_threshold>
+
+See L</compression_threshold>
+
 =item * C<debug>
 
 Optional. If set with a positive integer, this will activate debugging message
