@@ -21,6 +21,7 @@ BEGIN
     use Devel::Confess;
     use Apache2::Request;
     use Apache2::Const -compile => qw( :common :http );
+    use Apache2::Log ();
     use Apache2::Response ();
     use Apache2::RequestIO ();
     use Apache2::RequestRec ();
@@ -318,6 +319,22 @@ sub get_http_message { return( Apache2::API::Status->status_message( $_[1], $_[2
 
 sub get_status_line { return( shift->_try( '_request', 'status_line', @_ ) ); }
 
+sub header
+{
+    my $self = shift( @_ );
+    return( $self->error( "No header field name was provided to retrieve its value." ) ) if( !scalar( @_ ) );
+    my $field = shift( @_ );
+    my $hdrs = $self->headers || return( $self->pass_error );
+    if( scalar( @_ ) > 1 )
+    {
+        return( $hdrs->set( "$field" => @_ ) );
+    }
+    else
+    {
+        return( $hdrs->get( "$field" ) );
+    }
+}
+
 sub headers { return( shift->_headers( 'err_headers_out', @_ ) ); }
 
 sub headers_out { return( shift->_headers( 'headers_out', @_ ) ); }
@@ -549,14 +566,32 @@ sub _headers
 {
     my $self = shift( @_ );
     my $type = shift( @_ ) ||
-        return( $self->error( "No header type was specified." ) );
+        return( $self->error({
+            message => "No header type was specified.",
+            want => [qw( hash )],
+        }) );
     my $req = $self->_request ||
-        return( $self->error( "No Apache2::RequestRec found!" ) );
+        return( $self->error({
+            message => "No Apache2::RequestRec found!",
+            want => [qw( hash )],
+        }) );
     my $code = $req->can( $type ) ||
-        return( $self->error( "Header type '$type' is unsupported by Apache2::RequestRec" ) );
+        return( $self->error({
+            message => "Header type '$type' is unsupported by Apache2::RequestRec",
+            want => [qw( hash )],
+        }) );
     my $apr = $code->( $req ) ||
-        return( $self->error( "Could not get an APR::Table object from Apache2::RequestRec->${type}" ) );
-    return( $self->error( "Object retrieved from Apache2::RequestRec->${type} is not an APR::Table object." ) ) if( !$self->_is_a( $apr => 'APR::Table' ) );
+        return( $self->error({
+            message => "Could not get an APR::Table object from Apache2::RequestRec->${type}",
+            want => [qw( hash )],
+        }) );
+    if( !$self->_is_a( $apr => 'APR::Table' ) )
+    {
+        return( $self->error({
+            message => "Object retrieved from Apache2::RequestRec->${type} is not an APR::Table object.",
+            want => [qw( hash )],
+        }) );
+    }
     if( scalar( @_ ) && !( @_ % 2 ) )
     {
         for( my $i = 0; $i < scalar( @_ ); $i += 2 )
@@ -757,6 +792,14 @@ Apache2::API::Response - Apache2 Outgoing Response Access and Manipulation
     $resp->flush;
     my $msg = $resp->get_http_message( 429 => 'ja_JP' );
     my $string = $resp->get_status_line;
+    my $content_type = $resp->headers( 'Content-Type' );
+    # or (since it is case insensitive)
+    my $content_type = $resp->headers( 'content-type' );
+    # or
+    my $content_type = $resp->headers->{'Content-Type'};
+    $resp->header( 'Content-Type' => 'text/plain' );
+    # or
+    $resp->headers->{'Content-Type'} = 'text/plain';
     # APR::Table object
     my $headers = $resp->headers;
     my $headers = $resp->headers_out;
